#
# spec file for package dasher
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           dasher
Version:        5.0.0+199
Release:        1.2
Summary:        Zooming Predictive Text Entry System
License:        GPL-2.0-or-later
Group:          System/GUI/GNOME
URL:            https://gitlab.gnome.org/GNOME/dasher
Source:         %{name}-%{version}.tar.xz

BuildRequires:  c++_compiler
BuildRequires:  c_compiler
BuildRequires:  fdupes
BuildRequires:  gettext-devel
BuildRequires:  gnome-common
BuildRequires:  intltool
BuildRequires:  libexpat-devel
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  yelp-tools
BuildRequires:  pkgconfig(atspi-2) >= 2.11
BuildRequires:  pkgconfig(cairo)
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(glib-2.0) >= 2.6
BuildRequires:  pkgconfig(gsettings-desktop-schemas)
BuildRequires:  pkgconfig(gthread-2.0)
BuildRequires:  pkgconfig(gtk+-3.0)

Obsoletes:      %{name}-data-recommended < 0.5.0
Provides:       %{name}-data-recommended = %{version}
Obsoletes:      %{name}-data-extras < 0.5.0
Provides:       %{name}-data-extras = %{version}

%description
Dasher is a zooming predictive text entry system, designed for
situations where keyboard input is impractical (for instance:
accessibility or PDAs). It is usable with greatly limited amounts of
physical input while still allowing high rates of text entry.

%lang_package

%prep
%autosetup -p1
NOCONFIGURE=1 ./autogen.sh

%build
%configure \
	--with-pic \
	%{nil}
%make_build

%install
%make_install
%find_lang %{name} %{?no_lang_C}
%fdupes %{buildroot}%{_prefix}

%files
%license COPYING
%doc AUTHORS ChangeLog MAINTAINERS NEWS README.md
%{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/%{name}
%{_datadir}/help/C/%{name}
%{_datadir}/icons/hicolor/48x48/apps/%{name}.png
%{_datadir}/icons/hicolor/scalable/apps/%{name}.svg
%{_mandir}/man?/*%{ext_man}

%files lang -f %{name}.lang

%changelog
* Thu Feb 27 2025 bjorn.lie@gmail.com
- Update to version 5.0.0+199:
  * Add roman vowels with a macron (e.g. ō) to the Japanese Kanna
    with Romaji alphabet, and minor reordering of the alphabet
    groups.
  * Alphabet improvements
  * configure.ac: Replace defunct Bugzilla with GNOME GitLab
  * docs: Replace defunct Bugzilla with GNOME GitLab
  * Adjust text label size and line thickness to account for 2
    pixels per 'point' in with high DPI displays.
  * Fixes to get rendering working correctly on recent mac hardware
    and OS.
  * Minor 'delete' fix and whitespace correction.
  * Use gtk3 draw event rather than gtk2 expose_event.
    gtk__cairo_should_draw_window() presence wasn't being tested.
  * g/c Gdk2 based drawing code (aka the without-cairo option)
  * g/c Qt Extended (Qtopia) which was discontinued over a decade
    ago.
  * g/c The GPE Palmtop Environment which had its last release over
    a decade ago.
  * Point to GitLab instead of Bugzilla (deprecated) in README
  * Avoid deprecated function
  * Remove extern "C" warpper around atspi/glib headers inclusion
  * Tidy away QTE support, the crux of which was already commented
    out.
  * gtk_show_uri deprecated in favour of gtk_show_uri_on_window in
    gtk 3.22
  * Drop support for Gtk2 - Gtk4 is here!
  * Fix comment after 73b1e4a
  * Remove cspi/bonobo support.
  * configure: Ada removed support for GSettings etc. in 2015
  * Remove Maemo support.
  * Remove IOstreamDasherEdit.*
  * Drop html markup
  * Drop trailing spaces
  * Fix socket vs <functional> conflict.
  * Fix clearly untested "Migrate from gnome-doc-utils"
  * Correctly fall back system font when no Dasher Font has been
    selected in preferences
  * Fix appveyor build status URL
  * Fix appveyor error about project cannot be found
  * Updated translations.
- Switch back to gnome gitlab as source url. Original upstream have
  come back to life. Use current head.
- Following upstream changes, drop no longer needed
  update-desktop-files, pkgconfig(gtk+-2.0) and pkgconfig(xtst)
  BuildRequires. Clean up spec.
- Drop patches fixed upstream:
  * dasher-5.0.0-sys-stat.patch
  * gnome-doc-utils-depr.patch
  * 0001-Remove-extern-C-warpper-around-atspi-glib-headers-in.patch
* Mon Aug 19 2024 Dominique Leuenberger <dimstar@opensuse.org>
- BuildRequire gettext-devel instead of gettext: allow OBS to
  shortcut through gettext-runtime-mini.
* Mon Nov  6 2023 Dominique Leuenberger <dimstar@opensuse.org>
-  Fix build with RPM 4.19: unnumbered patches are no longer
  supported.
* Sat Feb 12 2022 bjorn.lie@gmail.com
- Update to version 5.0.0:
  + Gtk2/FileUtils: Include sys/stat.h
  + Preparation for 5.0 beta release.
  + Win32 -- turned on whole program optimization and unused code
    removal
  + Removed obsolete targets from Win32 projects.
  + Generalised pre set notifications for parameters and reworked
    alphabet history.
  + Tweaks to control boxes.
  + Cleanup. No more WinCE code.
  + Removed obsolate PocketPC projects.
  + Cleanup in Common project.
  + Turn draw mouse position on by default.
  + DasherInterface->Done was not really stopping dasher.
  + Errors in training file should not stop dasher.
  + Removed ugly messages about speed changes.
  + Countless changes and fixes.
  + Port away from gconf2.
  + Updated translations
- Start fresh with gitcheckout from new upstream.
- Drop patches and source files no longer needed:
  + pre_checkin.sh
  + locale-map.txt
  + dasher.spec.in,
  + dasher-linkX11.patch
  + dasher-gcc6.patch
  + dasher-data-lang.sh
- Add upstream build/bug fix patches:
  + dasher-5.0.0-sys-stat.patch
  + gnome-doc-utils-depr.patch
  + 0001-Remove-extern-C-warpper-around-atspi-glib-headers-in.patch
- BuildRequires/Requires/Recommends/Suggests were dropped and
  replaced with more modern variants.
- Sub-packages dasher-data-recommended and dasher-data-extra were
  both dropped and Obsoleted and Provided via main package.
* Thu Sep 16 2021 Stanislav Brabec <sbrabec@suse.com>
- Remove obsolete translation-update-upstream support
  (jsc#SLE-21105).
* Sat Jan 25 2020 Dominique Leuenberger <dimstar@opensuse.org>
- No longer recommend -lang: supplements are in use
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Mon Nov 14 2016 toddrme2178@gmail.com
- Fix some typos in the language code mapping.
- Upgrade .spec.in file to produce the correct spec file.
* Sat Jun 18 2016 dimstar@opensuse.org
- Add dasher-gcc6.patch: Fix build with gcc 6 (bool can't be used
  as return value for functions returning string) (boo#985108).
* Mon Feb 10 2014 mgorse@suse.com
- Remove libgnomeui-devel BuildRequires, add gconf2-devel and
  gtk2-devel BuildRequires. Dasher doesn't check for libgnomeui
  if AT-SPI is disabled and does not appear to use it.
* Sat Feb  8 2014 mgorse@suse.com
- Disable AT-SPI (1) support. It will not work correctly anyhow
  since GNOME 3 uses AT-SPI 2:
  + Pass --disable-a11y to configure.
  + Drop at-spi-devel BuildRequires.
- Add pkgconfig(xtst) BuildRequires: needed if AT-SPI is not
  enabled.
* Fri Mar  1 2013 dimstar@opensuse.org
- Spec-cleanup using format_spec_file service.
* Sun Sep 18 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
  (cf. packaging guidelines)
- Use %%_smp_mflags for parallel build
* Thu Aug 25 2011 dimstar@opensuse.org
- Add dasher-linkX11.patch: Remove functions that would require us
  to link against X11: those functions have not been called for a
  long time. See bgo#657307.
* Mon Jun 27 2011 vuntz@opensuse.org
- Drop gnome-speech-devel BuildRequires: gnome-speech is
  deprecated. There is code in git to use speech-dispatcher, so the
  next version will have speech features again.
* Sun Feb 13 2011 vuntz@opensuse.org
- Call relevant macros in %%post/%%postun:
  + %%desktop_database_post/postun because the package ships at
    least one desktop file.
  + %%icon_theme_cache_post/postun because the package ships themed
    icons.
- Pass %%{?no_lang_C} to %%find_lang so that english documentation
  can be packaged with the program, and not in the lang subpackage.
- Change Requires of lang subpackage to Recommends, since the
  english documentation is not there anymore.
* Sat May 29 2010 vuntz@opensuse.org
- Create data-recommended and data-extras subpackages and move
  alphabets files there, to make the main package smaller. Those
  packages also provide specific locales for dasher.
- Add dasher-data-lang.sh script and locale-map.txt map file to
  determine which file should go in which package.
- Add Recommends on data-recommended and Suggests on data-extras.
* Tue Mar 23 2010 dimstar@opensuse.org
- Remove en@shaw locale on openSUSE <= 11.2.
* Sun Mar 14 2010 dimstar@opensuse.org
- Update to version 4.11:
  + New two-push, one button, dynamic mode (which reduces the
    up-and-down motion of one button dynamic mode).
  + Fix switching alphabets and then deleting across languages.
  + Gtk: Fix blank start window caused by new Gtk library.
  + Gtk: Don't use libglade.
- Changes from version 4.10.2
  + MacOS X version uses OpenGL
  + Fix compass mode (broken by letter leakage fix in 4.10.0)
- Remove libstdc++ and libglade-devel BuildRequires
- Clean specfile using spec-cleaner.
* Tue Aug  4 2009 vuntz@novell.com
- Do not package omf files twice.
* Tue Apr 28 2009 vuntz@novell.com
- Update to version 4.10.1:
  + Fix crash when scrolling precisely vertically.
  + Gtk: the speed spin button on the main screen now changes and
    is in synch with the value in preferences.
* Tue Mar 17 2009 vuntz@novell.com
- Update to version 4.10.0:
  + Fix click modes where letters near the edge of the selection
    box to "leak" out so they could not be selected.
  + Fix UTF-8 bug so e.g., Japanese and Hebrew work.
  + Many code fixes (see ChangeLog)
  + Updated translations.
- Remove unneeded autoreconf, intltoolize calls.
- Do not add DocPath to desktop file: yelp doesn't need this.
- Remove checks for old versions of openSUSE.
- Remove sr@Latn to sr@latin workaround (fixed upstream)
- Stop removing uz@cyrillic.
- Do not manually install gconf schemas: the tarball does this.
- Remove unneeded BuildRequires: docbook_4, libwnck-devel,
  perl-XML-Parser, scrollkeeper.
* Mon Feb 16 2009 sbrabec@suse.cz
- Added support for translation-update-upstream (FATE#301344).
* Sat Jan 31 2009 vuntz@novell.com
- Use sr@latin instead of sr@Latn.
* Sat Aug 30 2008 crrodriguez@suse.de
- fix build
* Wed Jun 18 2008 maw@suse.de
- Update to version 4.9.0:
  + New project branch, with various bugfixes and improvements.
* Thu Apr 10 2008 maw@suse.de
- Update to version 4.7.3:
  + Misc. bugfixes
- Drop dasher-includes.patch.
* Thu Mar  6 2008 maw@suse.de
- Fix the build when against newer versions of intltool.
* Wed Feb 20 2008 rodrigo@suse.de
- Upstreamed patch and tag .spec file accordingly
* Fri Feb  1 2008 maw@suse.de
- Update to version 4.7.0:
  + New development series
- Remove abuild.patch.
- Remove dasher-gcc4.3-fixes.patch, but add dasher-includes.patch,
  which does very nearly the same thing!
* Tue Nov  6 2007 maw@suse.de
- Add dasher-gcc4.3-fixes.patch.
* Tue Sep 18 2007 maw@suse.de
- Update to version 4.6.0:
  + Updated translations
- Add abuild.patch.
* Mon Aug  6 2007 mauro@suse.de 
- Split out a -lang subpackage
- Added %%fdupes stuff
* Wed Aug  1 2007 mauro@suse.de
- Update to version 4.5.2
- Bugfixes, new CTW language model, updated translations.
* Mon Jul  9 2007 maw@suse.de
- Update to version 4.5.1
- Bugfixes, code cleanups, and updated translations.
* Thu May 10 2007 pgajdos@suse.cz
- removed gnome-icon-theme from BuildRequires [#247450]
* Fri Apr 27 2007 sbrabec@suse.cz
- Do not call meinproc (#227624).
* Wed Apr 11 2007 maw@suse.de
- Update to version 4.4.1 which as minor bugfixes and translation
  updates.
* Fri Mar 30 2007 maw@suse.de
- Update to version 4.4.0
- Remove upstreamed autobuild-warnings.patch
- Code cleanups
- b.g.o 412217, 407773, 398103, 346973.
* Thu Mar  8 2007 sbrabec@suse.cz
- Removed obsolete hicolor icon symlink (#248676).
* Wed Feb 28 2007 maw@suse.de
- Remove dasher-return-random-data.patch, dasher-warning.patch,
  and dasher-4.2.0-unused-code.patch, which are now upstream
- Add autobuild-warnings.patch.
* Tue Feb 27 2007 maw@suse.de
- Update to version 4.3.4
- Remove dasher-desktop.patch, which is now upstream.
* Wed Feb 21 2007 mvaner@suse.cz
- Fixed uninitiated variable (#230228)
  - unused-code.patch
* Thu Jan  4 2007 sbrabec@suse.cz
- Prefix changed to /usr.
- Spec file cleanup.
* Fri Oct 13 2006 aj@suse.de
- Adjust BuildRequires for gnome-doc-utils.
- Cleanup BuildRequires.
* Wed Sep 13 2006 jhargadon@suse.de
- update to version 4.2.0
- translation updates
- Documentation update
- Bugfixes
* Wed Sep  6 2006 anosek@suse.cz
- fixed compiler warning: missing return statement at end
  of non-void function [#203479] (warning.patch)
* Wed Aug 30 2006 jhargadon@suse.de
- update to version 4.1.10
- Minor update to UI
- Bugfixes
- Updated translations
* Thu Aug 17 2006 jhargadon@suse.de
- update to version 4.1.9
- bug 350117 - crash on dasher
- bug 350071 - Translation credits string
* Tue Aug  1 2006 gekker@suse.de
- Update to version 4.1.8
  * Improvements to dynamic button modes
  * Many bugfixes
  * Redesigned preferences dialogue
  * Updated two button dynamic mode
  * Improved interaction with desktop environment
  * Fixes to build system
  * Considerable internal rewriting
  * Introduction of 'application styles' - the aim here is to improve
    integration with the desktop.
  * Improved button control.
  * Improved support for Hiragana to Kanji conversion.
  * Prototype support for the Maemo environment as used on the Nokia N770.
  * Cairo support ported from 3.2 branch
  * (Partial) button mode support
  * Infinite back off
  * Improved symbol grouping in alphabets
  * New status bar, with 'favourite' alphabet selection
  * Updated translations
  * Panel detection code fixed
  * Fixed a speech crash bug
  * Use gtkfilechooser
  * X server portability fixes
  * Behaves intelligently when it comes to deleting characters
  * Fix various nasty things that broke switching between accessible applications
* Fri Apr 14 2006 dobey@suse.de
- Replace icon with new version from upstream
* Tue Feb 28 2006 sbrabec@suse.cz
- Fixed BuildRequires.
* Tue Feb 28 2006 sbrabec@suse.cz
- Use kdelibs3-doc in BuildRequires for meinproc (#153635#c14).
* Fri Feb 24 2006 sbrabec@suse.cz
- Improved Categories.
* Fri Feb 17 2006 sreeves@suse.de
- Update .desktop file (Name, GenericName, Comment, DocPath)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Jan 18 2006 sbrabec@suse.cz
- Updated to version 3.2.19.
* Mon Sep  5 2005 gekker@suse.de
- Updated to version 3.2.18 (GNOME 2.12)
* Mon Sep  5 2005 sbrabec@suse.cz
- Updated to version 3.2.17.
* Tue Aug 23 2005 gekker@suse.de
- Update to version 3.2.16
* Wed Mar  9 2005 gekker@suse.de
- Update to version 3.2.15 (GNOME 2.10).
- remove upstreamed patch for libwnck API breakage
* Mon Mar  7 2005 gekker@suse.de
- Patch the libwnck API breakage
* Thu Feb 10 2005 gekker@suse.de
- Updated to version 3.2.13
* Fri Jan 14 2005 sbrabec@suse.cz
- Updated to version 3.2.12.
* Tue Dec 14 2004 hvogel@suse.de
- fix desktop file
* Wed Oct 27 2004 mmj@suse.de
- locale rename no to nb
* Mon Sep 20 2004 adrian@suse.de
- add %%suse_update_desktop_file (#45636)
* Tue Aug 31 2004 clahey@suse.de
- Don't --check as the docs don't validate.
* Wed Aug 25 2004 clahey@suse.de
- Cache dasher docs and have dasher show up in khelpcenter.
* Mon Aug 16 2004 ro@suse.de
- find Xtst lib on lib64
* Tue Jun  8 2004 sbrabec@suse.cz
- GNOME support work-around.
  http://bugzilla.gnome.org/show_bug.cgi?id=143332
- Added support for Czech language.
- Added Czech training text (with permission of the Institute of the
  Czech National Corpus).
* Tue May 11 2004 sbrabec@suse.cz
- Fixed gconftool-2 prerequirements.
* Tue May  4 2004 sbrabec@suse.cz
- New SuSE package, version 3.2.10 (GNOME 2.6).
